nvector package — nvector 0.7.5 documentation

# nvector package

## Geodesic functions

`closest_point_on_great_circle`(path, n_EB_E) | Returns closest point C on great circle path A to position B.
`cross_track_distance`(path, n_EB_E[, method, …]) | Returns cross track distance between path A and position B.
`euclidean_distance`(n_EA_E, n_EB_E[, radius]) | Returns Euclidean distance between positions A and B
`great_circle_distance`(n_EA_E, n_EB_E[, radius]) | Returns great circle distance between positions A and B
`intersect`(path_a, path_b) | Returns the intersection(s) between the great circles of the two paths
`lat_lon2n_E`(latitude, longitude[, R_Ee]) | Converts latitude and longitude to n-vector.
`mean_horizontal_position`(n_EB_E) | Returns the n-vector of the horizontal mean position.
`n_E2lat_lon`(n_E[, R_Ee]) | Converts n-vector to latitude and longitude.
`n_EB_E2p_EB_E`(n_EB_E[, depth, a, f, R_Ee]) | Converts n-vector to Cartesian position vector in meters.
`p_EB_E2n_EB_E`(p_EB_E[, a, f, R_Ee]) | Converts Cartesian position vector in meters to n-vector.
`n_EA_E_and_n_EB_E2p_AB_E`(n_EA_E, n_EB_E[, …]) | Returns the delta vector from position A to B decomposed in E.
`n_EA_E_and_p_AB_E2n_EB_E`(n_EA_E, p_AB_E[, …]) | Returns position B from position A and delta.
`n_EA_E_and_n_EB_E2azimuth`(n_EA_E, n_EB_E[, …]) | Returns azimuth from A to B, relative to North:
`n_EA_E_distance_and_azimuth2n_EB_E`(n_EA_E, …) | Returns position B from azimuth and distance from position A
`on_great_circle`(path, n_EB_E[, radius, atol]) | True if position B is on great circle through path A.
`on_great_circle_path`(path, n_EB_E[, radius, …]) | True if position B is on great circle and between endpoints of path A.

## Rotation matrices and angles

`E_rotation`([axes]) | Returns rotation matrix R_Ee defining the axes of the coordinate frame E.
`n_E2R_EN`(n_E[, R_Ee]) | Returns the rotation matrix R_EN from n-vector.
`n_E_and_wa2R_EL`(n_E, wander_azimuth[, R_Ee]) | Returns rotation matrix R_EL from n-vector and wander azimuth angle.
`R_EL2n_E`(R_EL) | Returns n-vector from the rotation matrix R_EL.
`R_EN2n_E`(R_EN) | Returns n-vector from the rotation matrix R_EN.
`R2xyz`(R_AB) | Returns the angles about new axes in the xyz-order from a rotation matrix.
`R2zyx`(R_AB) | Returns the angles about new axes in the zxy-order from a rotation matrix.
`xyz2R`(x, y, z) | Returns rotation matrix from 3 angles about new axes in the xyz-order.
`zyx2R`(z, y, x) | Returns rotation matrix from 3 angles about new axes in the zyx-order.

## Misc functions

`deg`(\*rad_angles) | Converts angle in radians to degrees.
`mdot`(a, b) | Returns multiple matrix multiplications of two arrays
`nthroot`(x, n) | Returns the n’th root of x to machine precision
`rad`(\*deg_angles) | Converts angle in degrees to radians.
`select_ellipsoid`(name) | Returns semi-major axis (a), flattening (f) and name of ellipsoid
`unit`(vector[, norm_zero_vector]) | Convert input vector to a vector of unit length.

## OO interface to Geodesic functions

`delta_E`(point_a, point_b) | Returns cartesian delta vector from positions a to b decomposed in E.
`delta_N`(point_a, point_b) | Returns cartesian delta vector from positions a to b decomposed in N.
`delta_L`(point_a, point_b[, wander_azimuth]) | Returns cartesian delta vector from positions a to b decomposed in L.
`diff_positions`(\*args, \*\*kwds) | diff_positions is deprecated!
`ECEFvector`(pvector[, frame, scalar]) | Geographical position given as Cartesian position vector in frame E
`FrameB`(position[, yaw, pitch, roll, degrees]) | Body frame
`FrameE`([a, f, name, axes]) | Earth-fixed frame
`FrameN`(position) | North-East-Down frame
`FrameL`(position[, wander_azimuth]) | Local level, Wander azimuth frame
`GeoPoint`(latitude, longitude[, z, frame, …]) | Geographical position given as latitude, longitude, depth in frame E.
`GeoPath`(point_a, point_b) | Geographical path between two positions in Frame E
`Nvector`(normal[, z, frame]) | Geographical position given as n-vector and depth in frame E
`Pvector`(pvector, frame[, scalar]) | Cartesian position vector in relative to a frame.